===================
Roadmap
===================

Status
=======

* workdir support

  * complete

    * bzr
    * hg
    * svn

  * messy

    * darcs
    * git

* repository access **in progress**

  * hg **in progress**

* history browsing  **planning**
* branch management **planning**
